@@ -4,6 +4,7 @@ from .country import Country
 from account_generator_helper.countries import Counties
 from typing import List
 
+from ..exceptions import NoCountyFound
 
 headers = {
   'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/100.0.4896.75 Safari/537.36'
@@ -24,16 +25,20 @@ class Receive:
         """
         pass
 
-    def get_country(self, country: Counties) -> Country:
+    def get_country(self, phone_country: Counties) -> Country:
         """
         Method returns object of the country, from this object you can get the phone number of this country.
 
-        :param country: Country.
+        :param phone_country: Country.
         :return: Country object.
         """
         if not self._countries:
             self.get_counties()
-        return self._countries.get(country, None)
+        result = self._countries.get(phone_country, None)
+        if not result:
+            raise NoCountyFound()
+
+        return result
 
     def get_random_country(self) -> Country:
         """
@@ -42,4 +47,4 @@ class Receive:
         return random.choice(self.get_counties())
 
     def __repr__(self):
-        return '<Receive country_count={}>'.format(len(self._countries))
+        return '(Receive country_count={})'.format(len(self._countries))
